@@ -4,8 +4,7 @@
 #include "mapping/BarycentricBaseMapping.hpp"
 #include "mapping/Polation.hpp"
 
-namespace precice {
-namespace mapping {
+namespace precice::mapping {
 
 /**
  * @brief Mapping using orthogonal projection to nearest triangle/edge/vertex and
@@ -19,9 +18,11 @@ public:
   /// Computes the projections and interpolation relations.
   void computeMapping() final override;
 
+  /// name of the np mapping
+  std::string getName() const final override;
+
 private:
   logging::Logger _log{"mapping::NearestNeighborProjectionMapping"};
 };
 
-} // namespace mapping
-} // namespace precice
+} // namespace precice::mapping
