@@ -48,11 +48,13 @@ public:
       const xml::ConfigurationContext &context,
       xml::XMLTag                     &callingTag) override;
 
+  std::size_t nParticipants() const;
+
   /// Returns all configured participants.
   const std::vector<impl::PtrParticipant> &getParticipants() const;
 
   /// Returns a participant with the given name
-  const impl::PtrParticipant getParticipant(const std::string &participantName) const;
+  const impl::PtrParticipant getParticipant(std::string_view participantName) const;
 
   std::set<std::string> knownParticipants() const;
 
